@@ -122,7 +122,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 			commit_range = Some(format!("{}..{}", tag1, tag2));
 		}
 	}
-	let commits = repository.commits(commit_range)?;
+	let commits = repository.commits(commit_range, args.commit_path)?;
 
 	// Update tags.
 	if let Some(tag) = args.tag {
@@ -145,7 +145,11 @@ pub fn run(mut args: Opt) -> Result<()> {
 	for git_commit in commits.into_iter().rev() {
 		let commit = Commit::from(&git_commit);
 		let commit_id = commit.id.to_string();
-		releases[release_index].commits.push(commit);
+		if args.sort == "newest" {
+			releases[release_index].commits.insert(0, commit);
+		} else {
+			releases[release_index].commits.push(commit);
+		}
 		if let Some(tag) = tags.get(&commit_id) {
 			releases[release_index].version = Some(tag.to_string());
 			releases[release_index].commit_id = Some(commit_id);
